import QtQuick 2.0
import MuseScore 1.0
import QtQuick.Controls 1.2

MuseScore {
      version:  "1.0"
      description: "This plugin checks a score whether it is playable with an 30notes music box"
      menuPath: "Plugins.CheckPlayability.MusicBox30"
      width:  150
      height: 100

      property variant notplayable : "#ff0000"
      property variant playable : "#000000"
      property variant playables : [53, 55, 60, 62, 64, 65, 67, 69, 70, 
            71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85,
            86, 87, 88, 89, 91, 93]
      property variant message : "All notes are playable."
      pluginType: "dialog"


      function checkPlayability(note) {
            for (var i = 0; i < playables.length; i++) {
                  if (note.pitch == playables[i]) {
                        note.color = playable;
                        note.play = true;
                        return true;
                        }
            }
            note.color = notplayable;
            note.play = false;
            return false;
         }

      function undoCheckPlayability(note) {
            note.color = playable;
            note.play = true;
            return false;
         }



      Component.onCompleted: {
            console.log("Check playability for Ariston");
            if (typeof curScore === 'undefined')
                  Qt.quit();

            message.text = "All notes are playable."

            for (var track = 0; track < curScore.ntracks; ++track) {
                  var segment = curScore.firstSegment();
                  while (segment) {
                        var element = segment.elementAt(track);
                        if (element) {
                              var notes = element.notes;
                              if (notes) {
                                    for (var i = 0; i < notes.length; i++) {
                                        if (checkPlayability(notes[i]) == false) {
                                           message.text = "Some notes are not playable.\nI colored them in red\nand muted them.";
                                           message.color = "red"
                                          }
                                    }
                              }
                        }
                        segment = segment.next;
                  }
            }
            console.log(message);
         }
         

    Rectangle {         
        color: "white"
        anchors.fill: parent
        height: 150
        width: 200

        Text {
            id: message
            anchors.fill: parent
            horizontalAlignment: Text.AlignHCenter
            verticalAlignment: Text.AlignVCenter
            text: ""
            }

        Button {
            id: okbutton
            text: "OK"
            onClicked: Qt.quit()
            anchors.left: parent.left
            anchors.bottom: parent.bottom
            }

        Button {
            id: undobutton
            text: "Undo"
            onClicked: undo()
            anchors.right: parent.right
            anchors.bottom: parent.bottom
            }
        }

    function undo() {
            for (var track = 0; track < curScore.ntracks; ++track) {
                  var segment = curScore.firstSegment();
                  while (segment) {
                        console.log(segment.name)
                        var element = segment.elementAt(track);
                        if (element) {
                              var notes = element.notes;
                              if (notes) {
                                    for (var i = 0; i < notes.length; i++) {
                                        undoCheckPlayability(notes[i]);
                                          }
                                    }
                              }
                        }
                        segment = segment.next;
                  }
            Qt.quit()
            }
    }
